@@ -41,7 +41,11 @@ class GlpsolMIPConverter(ManagedSingletonPlugin):
         if from_type == ProblemFormat.mod and to_type == ProblemFormat.cpxlp:
             return True
         if from_type == ProblemFormat.mod and to_type == ProblemFormat.mps:
-            return True
+            if self.executable.service("ampl") is None:
+                #
+                # Only convert mod->mps with ampl
+                #
+                return True
         return False
 
     def apply(self, *args, **kwargs):
@@ -56,12 +60,13 @@ class GlpsolMIPConverter(ManagedSingletonPlugin):
         # MPS->LP conversion is ignored in coverage because it's not being
         #   used; instead, we're using pico_convert for this conversion
         #
+        modfile=''
         if args[1] == ProblemFormat.mps: #pragma:nocover
-            ofile="glpsol.mps"
-            cmd = cmd + " --check --wfreemps "+ofile
+            ofile = pyutilib.services.TempfileManager.create_tempfile(suffix = '.glpsol.mps')
+            cmd = cmd + " --check --name 'MPS model derived from "+os.path.basename(args[2])+"' --wfreemps "+ofile
         elif args[1] == ProblemFormat.cpxlp:
-            ofile="glpsol.lp"
-            cmd = cmd + " --check --wcpxlp "+ofile
+            ofile = pyutilib.services.TempfileManager.create_tempfile(suffix = '.glpsol.lp')
+            cmd = cmd + " --check --name 'MPS model derived from "+os.path.basename(args[2])+"' --wcpxlp "+ofile
         if len(args[2:]) == 1:
             cmd = cmd+" "+args[2]
         else:
@@ -69,7 +74,8 @@ class GlpsolMIPConverter(ManagedSingletonPlugin):
             # Create a temporary model file, since GLPSOL can only
             # handle one input file
             #
-            OUTPUT=open("glpsol.mod","w")
+            modfile = pyutilib.services.TempfileManager.create_tempfile(suffix = '.glpsol.mod')
+            OUTPUT=open(modfile,"w")
             flag=False
             #
             # Read the model file
@@ -95,10 +101,10 @@ class GlpsolMIPConverter(ManagedSingletonPlugin):
                 INPUT.close()
                 print >>OUTPUT, "end;"
             OUTPUT.close()
-            cmd = cmd+" glpsol.mod"
+            cmd = cmd+" "+modfile
         pyutilib.subprocess.run(cmd)
         if not os.path.exists(ofile):       #pragma:nocover
             raise pyutilib.common.ApplicationError, "Problem launching 'glpsol' to create "+ofile
-        if os.path.exists("glpsol.mod"):
-            os.remove("glpsol.mod")
+        if os.path.exists(modfile):
+            os.remove(modfile)
         return (ofile,),None # empty variable map
