@@ -46,27 +46,25 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
 
         return False
 
-    def apply(self, *args, **kwargs):
+    def apply(self, *args, **kwds):
         """
         Generate a NL or LP file from Pyomo, and then do subsequent
         conversions.
         """
+
         import coopr.pyomo
-        capabilities = kwargs.pop("capabilities", None)
+        capabilities = kwds.pop("capabilities", None)
+        generate_symbolic_labels = kwds.pop('generateSymbolicLabels',False)
 
         if isinstance(args[2], basestring):
             instance = None
         else:
             instance = args[2]
-        #elif isinstance(args[2], coopr.pyomo.Model):
-            #instance = args[2]
-        #else:
-            #raise IOError, "Bad data type for conversion: %s" % str(type(args[2]))
 
         if args[1] is ProblemFormat.cpxlp:
             problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix = '.pyomo.lp')
-            if not instance is None:
-                (problem_filename, varmap) = instance.write(filename=problem_filename, format=ProblemFormat.cpxlp, solver_capability=capabilities)
+            if instance is not None:
+                (problem_filename, varmap) = instance.write(filename=problem_filename, format=ProblemFormat.cpxlp, solver_capability=capabilities, generate_symbolic_labels=generate_symbolic_labels)
                 return (problem_filename,),varmap # no map file is necessary
             else:
                 model = coopr.pyomo.scripting.pyomo2lp(['--save-model',problem_filename,args[2]])
