@@ -133,7 +133,7 @@ class CBCSHELL(SystemCallSolver):
     def executable(self):
         executable = pyutilib.services.registered_executable("cbc")
         if executable is None:
-            pyutilib.component.core.PluginGlobals.env().log.error("Could not locate the 'cbc' executable, which is required for solver %s" % self.name)
+            pyutilib.component.core.PluginGlobals.env().log.warning("Could not locate the 'cbc' executable, which is required for solver %s" % self.name)
             self.enable = False
             return None
         return executable.get_path()
@@ -213,7 +213,7 @@ class CBCSHELL(SystemCallSolver):
             if "debug" in self.options:
                 opts.append("log=5")
             for key, val in _check_and_escape_options(self.options):
-                opts.append("%s=%s" % ( key, tmp ))
+                opts.append("%s=%s" % ( key, val ))
 
             env["CBC_options"] = " ".join(opts)            
 
@@ -223,7 +223,7 @@ class CBCSHELL(SystemCallSolver):
             if "debug" in self.options:
                 cmd.extend(["-log","5"])
             for key, val in _check_and_escape_options(self.options):
-                cmd.extend(['-'+key, tmp])
+                cmd.extend(['-'+key, val])
             cmd.extend(["-printingOptions", "all",
                         "-import", problem_files[0],
                         "-import",
@@ -285,8 +285,9 @@ class CBCSHELL(SystemCallSolver):
             if len(tokens) > 6 and tokens[0] == "Presolve" and tokens[6] == "infeasible":
                 soln.status = SolutionStatus.infeasible
                 soln.objective['__default_objective__'].value = None
-            if len(tokens) > 3 and tokens[0] == "Optimal" and tokens[1] == "objective":
+            if len(tokens) > 3 and tokens[0] == "Result" and tokens[2] == "Optimal":
                 soln.status = SolutionStatus.optimal
+            if len(tokens) >= 3 and tokens[0] == "Objective" and tokens[1] == "value:":
                 soln.objective['__default_objective__'].value=eval(tokens[2])
             if len(tokens) > 6 and tokens[4] == "best" and tokens[5] == "objective":
                 soln.objective['__default_objective__'].value=eval(tokens[6])
@@ -383,7 +384,10 @@ class CBCSHELL(SystemCallSolver):
 
         processing_constraints = None # None means header, True means constraints, False means variables.
         header_processed = False
-        INPUT = open(self.soln_file,"r")
+        try:
+            INPUT = open(self.soln_file,"r")
+        except IOError:
+            INPUT = []
         for line in INPUT:
             tokens = re.split('[ \t]+',line.strip())
             # these are the only header entries CBC will generate (identified via browsing CbcSolver.cpp)
@@ -457,7 +461,8 @@ class CBCSHELL(SystemCallSolver):
             else:
                 raise RuntimeError, "CBC plugin encountered unexpected line=("+line.strip()+") in solution file="+self.soln_file+"; expecting header, but found data!"
 
-        INPUT.close()
+        if not type(INPUT) is list:
+            INPUT.close()
 
 
 class MockCBC(CBCSHELL,mockmip.MockMIP):
