@@ -114,23 +114,18 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
                 "that is not found in the symbol map.  Does the instance "
                 "match the provided symbol map?" % ( obj.name, ))
 
-        from coopr.pyomo.base import Var, VarStatus
+        from coopr.pyomo.base import Var
 
-        doc = xml.dom.minidom.Document()
-        root_element = doc.createElement("CPLEXSolution")
-        root_element.setAttribute("version","1.0")
-        doc.appendChild(root_element)
+        # in principle, one could use a Python XML writer library like xml.dom.minidom.
+        # it works, but it is slow. hence, the explicit direct-write of XML below.
 
-        # currently not populated.
-        header_element = doc.createElement("header")
-        # currently not populated.
-        quality_element = doc.createElement("quality")
-        # definitely populated!
-        variables_element = doc.createElement("variables")
+        mst_file = open(self.warm_start_file_name, "w")
 
-        root_element.appendChild(header_element)
-        root_element.appendChild(quality_element)
-        root_element.appendChild(variables_element)
+        print >>mst_file, "<?xml version=\"1.0\" ?>"
+        print >>mst_file, "<CPLEXSolution version=\"1.0\">"
+        print >>mst_file, "<header/>"
+        print >>mst_file, "<quality/>"
+        print >>mst_file, "<variables>"
 
         # for each variable in the symbol_map, add a child to the
         # variables element.  Both continuous and discrete are accepted
@@ -142,20 +137,14 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
             for variable in block.active_components(Var).itervalues():
                 for index in variable:
                     var = variable[index]
-                    if var.status == VarStatus.unused or var.value is None \
-                            or var.fixed:
+                    if (var.stale is True) or (var.fixed is True):
                         continue
                     name = self._symbol_map.getSymbol(var, _error_labeler)
-
-                    variable_element = doc.createElement("variable")
-                    variable_element.setAttribute("name", name)
-                    variable_element.setAttribute("index", str(output_index))
-                    variable_element.setAttribute("value", str(var.value))
-                    variables_element.appendChild(variable_element)
+                    print >>mst_file, "<variable index=\"%d\" name=\"%s\" value=\"%f\" />" % (output_index, name, var.value)
                     output_index = output_index + 1
 
-        mst_file = open(self.warm_start_file_name,'w')
-        doc.writexml(mst_file, indent="    ", newl="\n")
+        print >>mst_file, "</variables>"
+        print >>mst_file, "</CPLEXSolution>"
         mst_file.close()
 
     # over-ride presolve to extract the warm-start keyword, if specified.
@@ -207,7 +196,7 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
     def executable(self):
         executable = pyutilib.services.registered_executable("cplex")
         if executable is None:
-            pyutilib.component.core.PluginGlobals.env().log.error("Could not locate the 'cplex' executable, which is required for solver %s" % self.name)
+            pyutilib.component.core.PluginGlobals.env().log.warning("Could not locate the 'cplex' executable, which is required for solver %s" % self.name)
             self.enable = False
             return None
         return executable.get_path()
@@ -311,6 +300,12 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
         #
         # Parse logfile lines
         #
+        
+        # caching for subsequent use - we need to known the problem sense before using this information.
+        # adding to plugin to cache across invocation of process_logfile and process_soln_file.
+        self._best_bound = None
+        self._gap = None
+
         for line in output.split("\n"):
             tokens = re.split('[ \t]+',line.strip())
             if len(tokens) > 3 and tokens[0] == "CPLEX" and tokens[1] == "Error":
@@ -361,6 +356,14 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
                     results.solver.status = SolverStatus.ok
                 results.solver.termination_condition = TerminationCondition.infeasible
                 results.solver.termination_message = ' '.join(tokens)
+            elif len(tokens) >= 10 and tokens[0] == "MIP" and tokens[2] == "Time" and tokens[3] == "limit" and tokens[6] == "feasible:":
+                # handle processing when the time limit has been exceeded, and we have a feasible solution.
+                results.solver.status = SolverStatus.ok
+                results.solver.termination_condition = TerminationCondition.maxTimeLimit
+                results.solver.termination_message = ' '.join(tokens)
+            elif len(tokens) >= 10 and tokens[0] == "Current" and tokens[1] == "MIP" and tokens[2] == "best" and tokens[3] == "bound":
+                self._best_bound = float(tokens[5])
+                self._gap = float(tokens[8].rstrip(','))
             # for the case below, CPLEX sometimes reports "true" optimal (the first case)
             # and other times within-tolerance optimal (the second case).
             elif (len(tokens) >= 4 and tokens[0] == "MIP" and tokens[2] == "Integer" and tokens[3] == "optimal") or \
@@ -433,6 +436,7 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
         soln_variable = soln.variable # caching for efficiency
         INPUT = open(self.soln_file,"r")
         results.problem.number_of_objectives=1
+        time_limit_exceeded = False
         mip_problem=False
         for line in INPUT:
             line = line.strip()
@@ -485,13 +489,9 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
                         constraint_name = field_value
                         constraint = soln.constraint[constraint_name]
                     elif (extract_duals is True) and (field_name == "dual"): # for LPs
-                        # assumes the name field is first.
-                        if float(field_value) != 0.0:
-                            constraint.dual = float(field_value)
+                        constraint.dual = float(field_value)
                     elif (extract_slacks is True) and (field_name == "slack"): # for MIPs
-                        # assumes the name field is first.
-                        if float(field_value) != 0.0:
-                            constraint.slack = float(field_value)
+                        constraint.slack = float(field_value)
             elif tokens[0].startswith("problemName"):
                 filename = (string.strip(tokens[0].split('=')[1])).lstrip("\"").rstrip("\"")
                 #print "HERE",filename
@@ -531,9 +531,11 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
                   elif solution_status == 3:
                     soln.status = SolutionStatus.infeasible
                     soln.gap = None                  
-                  elif solution_status >= 4: # we are flagging these as "error".
-                    soln.status = SolutionStatus.error
-                    soln.gap = None
+                  elif solution_status >= 4: 
+                      # we are flagging anything with a solution status >= 4 as an error, to possibly
+                      # be over-ridden as we learn more about the status (e.g., due to time limit exceeded).
+                      soln.status = SolutionStatus.error
+                      soln.gap = None
             elif tokens[0].startswith("solutionStatusString"):
                 solution_status = (string.strip(" ".join(tokens).split('=')[1])).lstrip("\"").rstrip("\"")
                 if solution_status in ["optimal", "integer optimal solution", "integer optimal, tolerance"]:
@@ -545,24 +547,49 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
                 elif solution_status in ["infeasible"]:
                     soln.status = SolutionStatus.infeasible
                     soln.gap = None
+                elif solution_status in ["time limit exceeded"]:
+                    # we need to know if the solution is primal feasible, and if it is, set the solution status accordingly.
+                    # for now, just set the flag so we can trigger the logic when we see the primalFeasible keyword.
+                    time_limit_exceeded = True
             elif tokens[0].startswith("MIPNodes"):
                 if mip_problem:
                     n = eval(eval(string.strip(" ".join(tokens).split('=')[1])).lstrip("\"").rstrip("\""))
                     results.solver.statistics.branch_and_bound.number_of_created_subproblems=n
                     results.solver.statistics.branch_and_bound.number_of_bounded_subproblems=n
+            elif tokens[0].startswith("primalFeasible") and (time_limit_exceeded is True):
+                primal_feasible = int((string.strip(" ".join(tokens).split('=')[1])).lstrip("\"").rstrip("\""))
+                if primal_feasible == 1:
+                    soln.status = SolutionStatus.feasible
+                    if (results.problem.sense == ProblemSense.minimize):
+                        results.problem.upper_bound = soln.objective['__default_objective__'].value
+                    else:
+                        results.problem.lower_bound = soln.objective['__default_objective__'].value
+                else:
+                    soln.status = SolutionStatus.infeasible
 
 
-        if not results.solver.status is SolverStatus.error and \
-            results.solver.termination_condition in [TerminationCondition.unknown,
-                        #TerminationCondition.maxIterations,
-                        #TerminationCondition.minFunctionValue,
-                        #TerminationCondition.minStepLength,
-                        TerminationCondition.globallyOptimal,
-                        TerminationCondition.locallyOptimal,
-                        TerminationCondition.optimal,
-                        #TerminationCondition.maxEvaluations,
-                        TerminationCondition.other]:
+        if self._best_bound is not None:
+            if results.problem.sense == ProblemSense.minimize:
+                results.problem.lower_bound = self._best_bound
+            else:
+                results.problem.upper_bound = self._best_bound
+        if self._gap is not None:
+            soln.gap = self._gap
+
+        if not results.solver.status is SolverStatus.error:
+            if results.solver.termination_condition in [TerminationCondition.unknown,
+                                                        #TerminationCondition.maxIterations,
+                                                        #TerminationCondition.minFunctionValue,
+                                                        #TerminationCondition.minStepLength,
+                                                        TerminationCondition.globallyOptimal,
+                                                        TerminationCondition.locallyOptimal,
+                                                        TerminationCondition.optimal,
+                                                        #TerminationCondition.maxEvaluations,
+                                                        TerminationCondition.other]:
                 results.solution.insert(soln)
+            elif (results.solver.termination_condition is TerminationCondition.maxTimeLimit) and (soln.status is not SolutionStatus.infeasible):
+                results.solution.insert(soln)                
+
         INPUT.close()
 
     def _postsolve(self):
