@@ -16,6 +16,8 @@ from coopr.opt.base import *
 from coopr.opt.results import *
 from coopr.opt.solver import *
 
+from coopr.pyomo.base.numvalue import value
+
 import mockmip
 import pyutilib.services
 import pyutilib.common
@@ -148,7 +150,7 @@ class CPLEXDirect(OptSolver):
 
         if isinstance(exp, expr._IdentityExpression):
             return self._evaluate_bound(exp._args[0])
-        elif exp.is_constant():
+        elif exp.is_constant() or exp.is_fixed():
             return exp()
         else:
             raise ValueError, "ERROR: nonconstant bound: " + str(exp)
@@ -230,7 +232,7 @@ class CPLEXDirect(OptSolver):
         labeler = CPLEXDirect._numeric_labeler()
         self._symbol_map = SymbolMap(pyomo_instance)
 
-        from coopr.pyomo.base import Var, VarStatus, Objective, Constraint, IntegerSet, BooleanSet, SOSConstraint
+        from coopr.pyomo.base import Var, Objective, Constraint, IntegerSet, BooleanSet, SOSConstraint
         from coopr.pyomo.base.objective import minimize, maximize
         from coopr.pyomo.expr import canonical_is_constant
 
@@ -261,17 +263,17 @@ class CPLEXDirect(OptSolver):
             for variable in block.active_components(Var).itervalues():
                 for ndx in variable:
                     var = variable[ndx]
-                    if (not var.active) or (var.status == VarStatus.unused) or var.fixed:
+                    if (not var.active) or var.fixed:
                         continue
                     var_names.append(self._symbol_map.getSymbol( var, labeler ))
                     if var.lb is None:
                         var_lbs.append(-cplex.infinity)
                     else:
-                        var_lbs.append(var.lb())
+                        var_lbs.append(value(var.lb))
                     if var.ub is None:
                         var_ubs.append(cplex.infinity)
                     else:
-                        var_ubs.append(var.ub())
+                        var_ubs.append(value(var.ub))
                     if isinstance(variable.domain, IntegerSet):
                         var_types.append(cplex_instance.variables.type.integer)
                         num_integer_variables += 1
@@ -504,7 +506,7 @@ class CPLEXDirect(OptSolver):
                 "that is not found in the symbol map.  Does the instance "
                 "match the provided symbol map?" % ( obj.name, ))
 
-        from coopr.pyomo.base import Var, VarStatus
+        from coopr.pyomo.base import Var
 
         labeler = CPLEXDirect._numeric_labeler()
         # the iteration order is identical to that used in generating
@@ -514,8 +516,7 @@ class CPLEXDirect(OptSolver):
         for variable in instance.active_components(Var).values():
             for index in variable: # TBD - change iteration style.
                 var = variable[index]
-                if (var.status == VarStatus.unused) or (var.value is None) \
-                        or var.fixed:
+                if (var.stale is True) or (var.fixed is True):
                     continue
                 name = self._symbol_map.getSymbol(var, _error_labeler)
                 variable_names.append(name)
@@ -529,6 +530,7 @@ class CPLEXDirect(OptSolver):
     def _presolve(self, *args, **kwds):
         from coopr.pyomo.base.PyomoModel import Model
 
+        self.suffixes = kwds.pop( 'suffixes', [] )
         self.tee = kwds.pop( 'tee', False )
         self.keepFiles = kwds.pop( 'keepFiles', False )
         self.warm_start_solve = kwds.pop( 'warmstart', False )
@@ -555,6 +557,8 @@ class CPLEXDirect(OptSolver):
             fname = self.options.write
             self._active_cplex_instance.write(fname)
         
+        # Handle other keywords
+
         # if the first argument is a string (representing a filename),
         # then we don't have an instance => the solver is being applied
         # to a file.
@@ -620,18 +624,52 @@ class CPLEXDirect(OptSolver):
 
     def _postsolve(self):
 
+        # the only suffixes that we extract from CPLEX are
+        # constraint duals, constraint slacks, and variable
+        # reduced-costs. scan through the solver suffix list
+        # and throw an exception if the user has specified
+        # any others.
+        extract_duals = False
+        extract_slacks = False
+        extract_reduced_costs = False
+        for suffix in self.suffixes:
+            flag=False
+            if re.match(suffix,"dual"):
+                extract_duals = True
+                flag=True
+            if re.match(suffix,"slack"):
+                extract_slacks = True
+                flag=True
+            if re.match(suffix,"rc"):
+                extract_reduced_costs = True
+                flag=True
+            if not flag:
+                raise RuntimeError,"***The CPLEX solver plugin cannot extract solution suffix="+suffix
+
+
         instance = self._active_cplex_instance
 
+        # Remove variables whose absolute value is smaller than CPLEX's epsilon from the results data
+        #instance.cleanup()
+
         results = SolverResults()
         results.problem.name = instance.get_problem_name()
-        results.problem.lower_bound = None
+        results.problem.lower_bound = None #instance.solution.
         results.problem.upper_bound = None
-        results.problem.number_of_variables = None
-        results.problem.number_of_constraints = None
+        results.problem.number_of_variables = instance.variables.get_num()
+        results.problem.number_of_constraints = instance.linear_constraints.get_num() \
+                                                + instance.quadratic_constraints.get_num() \
+                                                + instance.indicator_constraints.get_num() \
+                                                + instance.SOS.get_num()
         results.problem.number_of_nonzeros = None
-        results.problem.number_of_binary_variables = None
-        results.problem.number_of_integer_variables = None
-        results.problem.number_of_continuous_variables = None
+        results.problem.number_of_binary_variables = instance.variables.get_num_binary()
+        results.problem.number_of_integer_variables = instance.variables.get_num_integer()
+        results.problem.number_of_continuous_variables = instance.variables.get_num() \
+                                                            - instance.variables.get_num_binary() \
+                                                            - instance.variables.get_num_integer() \
+                                                            - instance.variables.get_num_semiinteger()
+                                                            #TODO: Does this double-count semi-integers?
+                                                            #Should we also remove semi-continuous?
         results.problem.number_of_objectives = 1
 
         results.solver.name = "CPLEX "+instance.get_version()
@@ -641,18 +679,22 @@ class CPLEXDirect(OptSolver):
         results.solver.user_time = None
         results.solver.system_time = None
         results.solver.wallclock_time = None
-        results.solver.termination_condition = None
         results.solver.termination_message = None
 
         soln = Solution()
 
-        #Get solution status -- for now, if CPLEX returns > 4, mark as an error
+        #Get solution status -- for now, if CPLEX returns anything we don't recognize, mark as an error
         soln_status = instance.solution.get_status()
-        if soln_status == 1:
+        if soln_status in [1, 101, 102]:
+            results.solver.termination_condition = TerminationCondition.optimal
             soln.status = SolutionStatus.optimal
-        elif soln_status == 2:
+        elif soln_status in [2, 4, 118, 119]:
+            # Note: soln_status of 4 means infeasible or unbounded
+            #       and 119 means MIP infeasible or unbounded
+            results.solver.termination_condition = TerminationCondition.unbounded
             soln.status = SolutionStatus.unbounded
-        elif soln_status == 3:
+        elif soln_status in [3, 103]:
+            results.solver.termination_condition = TerminationCondition.infeasible
             soln.status = SolutionStatus.infeasible
         else:
             soln.status = SolutionStatus.error
@@ -668,8 +710,14 @@ class CPLEXDirect(OptSolver):
                 variable_name = variable_names[i]
                 soln.variable[variable_name] = {"Value" : variable_values[i], "Id" : len(soln.variable)}
 
-        results.solution.insert(soln)
-        #print type(instance),dir(instance.objective)
+            if extract_duals:
+                num_linear_constraints = instance.linear_constraints.get_num()
+                constraint_names = instance.linear_constraints.get_names()
+                dual_values = instance.solution.get_dual_values() 
+                for i in range(0,num_linear_constraints):
+                    soln.constraint[constraint_names[i]].dual = dual_values[i]
+
+            results.solution.insert(soln)
 
         self.results = results
 
