@@ -135,7 +135,7 @@ class GLPKSHELL ( SystemCallSolver ):
         if executable is None:
             msg = "Could not locate the 'glpsol' executable, which is "          \
                   "required for solver '%s'"
-            pyutilib.component.core.PluginGlobals.env().log.error(msg % self.name)
+            pyutilib.component.core.PluginGlobals.env().log.warning(msg % self.name)
             self.enable = False
             return None
 
@@ -172,7 +172,12 @@ class GLPKSHELL ( SystemCallSolver ):
             cmd.insert(0, self._timer)
         for key in self.options:
             opt = self.options[ key ]
-            cmd.extend(["--%s" % key, str(opt)])
+            if (opt.__class__ is str) and (opt.strip() == ''):
+                # Handle the case for options that must be
+                # specified without a value
+                cmd.append("--%s" % key)
+            else:
+                cmd.extend(["--%s" % key, str(opt)])
             #if isinstance(opt, basestring) and ' ' in opt:
             #    cmd.append('--%s "%s"' % (key, str(opt)) )
             #else:
@@ -321,7 +326,7 @@ class GLPKSHELL ( SystemCallSolver ):
                     elif 'z' == ntype:    # objective
                         obj_name = name
                     elif 'p' == ntype:    # problem name
-                        prob_name = name
+                        prob.name = name
                     else:                 # anything else is incorrect.
                         raise ValueError
 
