@@ -62,7 +62,7 @@ class GLPKSHELL_old(SystemCallSolver):
         if executable is None:
             msg = "Could not locate the 'glpsol' executable, which is " \
                   "required for solver '%s'"
-            PluginGlobals.env().log.error(msg % self.name)
+            PluginGlobals.env().log.warning(msg % self.name)
             self.enable = False
             return None
 
@@ -97,7 +97,12 @@ class GLPKSHELL_old(SystemCallSolver):
             cmd.insert(0, self._timer)
         for key in self.options:
             opt = self.options[ key ]
-            cmd.extend(["--%s" % key, str(opt)])
+            if (opt.__class__ is str) and (opt.strip() == ''):
+                # Handle the case for options that must be
+                # specified without a value
+                cmd.append("--%s" % key)
+            else:
+                cmd.extend(["--%s" % key, str(opt)])
             #if isinstance(self.options[key], basestring) \
             #       and ' ' in self.options[key]:
             #    cmd.append('--%s "%s"' % (key, str(self.options[key])))
