@@ -112,7 +112,7 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
                 "that is not found in the symbol map.  Does the instance "
                 "match the provided symbol map?" % ( obj.name, ))
 
-        from coopr.pyomo.base import Var, VarStatus
+        from coopr.pyomo.base import Var
 
         mst_file = open(self.warm_start_file_name,'w')
 
@@ -126,8 +126,7 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
             for variable in block.active_components(Var).itervalues():
                 for index in variable:
                     var = variable[index]
-                    if var.status == VarStatus.unused or var.value is None \
-                            or var.fixed:
+                    if (var.stale is True) or (var.fixed is True):
                         continue
                     name = self._symbol_map.getSymbol(var, _error_labeler)
                     print >>mst_file, name, var.value
@@ -187,7 +186,7 @@ class GUROBISHELL(ILMLicensedSystemCallSolver):
         else:
             executable = pyutilib.services.registered_executable("gurobi.sh")
         if executable is None:
-            pyutilib.component.core.PluginGlobals.env().log.error("Could not locate the 'gurobi' executable, which is required for solver %s" % self.name)
+            pyutilib.component.core.PluginGlobals.env().log.warning("Could not locate the 'gurobi' executable, which is required for solver %s" % self.name)
             self.enable = False
             return None
         return executable.get_path()
