@@ -84,7 +84,7 @@ class PICOSHELL(SystemCallSolver):
     def executable(self):
         executable = pyutilib.services.registered_executable("PICO")
         if executable is None:
-            pyutilib.component.core.PluginGlobals.env().log.error("Could not locate the 'PICO' executable, which is required for solver %s" % self.name)
+            pyutilib.component.core.PluginGlobals.env().log.warning("Could not locate the 'PICO' executable, which is required for solver %s" % self.name)
             self.enable = False
             return None
         return executable.get_path()
