@@ -98,7 +98,7 @@ class XPRESS_shell(ILMLicensedSystemCallSolver):
         
         executable = pyutilib.services.registered_executable("optimizer")
         if executable is None:
-            pyutilib.component.core.PluginGlobals.env().log.error("Could not locate the 'optimizer' executable, which is required for solver %s" % self.name)
+            pyutilib.component.core.PluginGlobals.env().log.warning("Could not locate the 'optimizer' executable, which is required for solver %s" % self.name)
             self.enable = False
             return None
         return executable.get_path()
