@@ -16,6 +16,8 @@ from coopr.opt.base import *
 from coopr.opt.results import *
 from coopr.opt.solver import *
 
+from coopr.pyomo.base.numvalue import value
+
 import mockmip
 from pyutilib.misc import Options
 from pyutilib.component.core import alias
@@ -95,7 +97,7 @@ class GLPKDirect ( OptSolver ):
 
 
     def _populate_glpk_instance ( self, model ):
-        from coopr.pyomo.base import Var, VarStatus, Objective, Constraint, \
+        from coopr.pyomo.base import Var, Objective, Constraint, \
                                      IntegerSet, BooleanSet, SOSConstraint
         from coopr.pyomo.expr import is_constant
 
@@ -148,8 +150,7 @@ class GLPKDirect ( OptSolver ):
             var_set = variable_list[ name ]
             for ii in var_set.keys():
                 var = var_set[ ii ]
-                if (not var.active) or (var.status is VarStatus.unused) \
-                   or (var.fixed is True):
+                if (not var.active) or (var.fixed is True):
                     continue
 
                 lb = ub = 0.0
@@ -157,14 +158,14 @@ class GLPKDirect ( OptSolver ):
                     var_type = GLP_FR
                 elif var.lb is None:
                     var_type = GLP_UB
-                    ub = var.ub()
+                    ub = value(var.ub)
                 elif var.ub is None:
                     var_type = GLP_LO
-                    lb = var.lb()
+                    lb = value(var.lb)
                 else:
                     var_type = GLP_DB
-                    lb = var.lb()
-                    ub = var.ub()
+                    lb = value(var.lb)
+                    ub = value(var.ub)
 
                 col += 1
                 colvar_map[ var.label ] = col
