@@ -14,6 +14,8 @@ from coopr.opt.base import *
 from coopr.opt.results import *
 from coopr.opt.solver import *
 
+from coopr.pyomo.base.numvalue import value
+
 import mockmip
 from pyutilib.misc import Options
 from pyutilib.component.core import alias
@@ -132,7 +134,7 @@ class gurobi_direct ( OptSolver ):
             return gurobi_python_api_exists
         else:
             if gurobi_python_api_exists is False:
-                raise ApplicationError, "No Gurobi <-> Python bindings available - Gurobi direct solver functionality is not available"
+                raise pyutilib.common.ApplicationError, "No Gurobi <-> Python bindings available - Gurobi direct solver functionality is not available"
             else:
                 return True        
 
@@ -145,7 +147,7 @@ class gurobi_direct ( OptSolver ):
 
     def _populate_gurobi_instance ( self, model ):
 
-        from coopr.pyomo.base import Var, VarStatus, Objective, Constraint, IntegerSet, BooleanSet, SOSConstraint
+        from coopr.pyomo.base import Var, Objective, Constraint, IntegerSet, BooleanSet, SOSConstraint
         from coopr.pyomo.expr import canonical_is_constant
 
         try:
@@ -164,16 +166,16 @@ class gurobi_direct ( OptSolver ):
         for block in all_blocks:
             for variable_name, variable in block.active_components(Var).iteritems():
                 for var_value in variable.itervalues():
-                    if (not var_value.active) or (var_value.status is VarStatus.unused) or (var_value.fixed is True):
+                    if (not var_value.active) or (var_value.fixed is True):
                         continue
     
                     lb = -GRB.INFINITY
                     ub = GRB.INFINITY
     
                     if var_value.lb is not None:
-                        lb = var_value.lb()
+                        lb = value(var_value.lb)
                     if var_value.ub is not None:
-                        ub = var_value.ub()
+                        ub = value(var_value.ub)
     
                     var_value_label = self._symbol_map.getSymbol(var_value, labeler)
     
@@ -218,20 +220,15 @@ class gurobi_direct ( OptSolver ):
 
             if 2 in expression:
                 obj_expr = QuadExpr(obj_expr)
-                keys = expression[2].keys()
-                for var_key in keys:
-                    if len(var_key) == 1:
-                        index = var_key.keys()[0]
-                        label = self._symbol_map.getSymbol(expression[-1][ index ], labeler)
-                        coef  = expression[ 2][ var_key ]
-                        obj_expr.addTerms(coef, pyomo_gurobi_variable_map[label], pyomo_gurobi_variable_map[label])
-                    else:
-                        index   = var_key.keys()[0]
-                        label_1 = self._symbol_map.getSymbol(expression[-1][ index ], labeler)
-                        index   = var_key.keys()[1]
-                        label_2 = self._symbol_map.getSymbol(expression[-1][ index ], labeler)
-                        coef    = expression[2][ var_key ]
-                        obj_expr.addTerms(coeff, pyomo_gurobi_variable_map[label_1], pyomo_gurobi_variable_map[label_2])
+                hash_to_variable_map = expression[-1]
+                for quad_repn, coef in expression[2].iteritems():
+                    gurobi_expr = QuadExpr(coef)
+                    for var_hash, exponent in quad_repn.iteritems():
+                        gurobi_var = pyomo_gurobi_variable_map[self._symbol_map.getSymbol(hash_to_variable_map[var_hash], labeler)]
+                        gurobi_expr *= gurobi_var 
+                        if exponent == 2:
+                            gurobi_expr *= gurobi_var
+                    obj_expr += gurobi_expr
 
         grbmodel.setObjective(obj_expr,sense=sense)       
  
@@ -271,7 +268,8 @@ class gurobi_direct ( OptSolver ):
                                 modelSOS.weights[key] )
         
         grbmodel.update()
-        
+
+        GUROBI_VERSION_MAJOR = gurobi.version()[0]
         for block in all_blocks:
             for constraint_name, constraint in block.active_components(Constraint).iteritems():
                 if constraint.trivial: 
@@ -285,6 +283,13 @@ class gurobi_direct ( OptSolver ):
                         continue  # not binding at all, don't bother
     
                     expression = constraint_data.repn
+
+                    offset = 0.0
+                    constraint_label = self._symbol_map.getSymbol(constraint, labeler)
+                    if 0 in expression:
+                        offset = constraint_data.repn[0][None]
+                    bound = -offset
+                    expr = LinExpr()
                     if 1 in expression: # first-order terms
     
                         linear_coefs = list()
@@ -297,42 +302,50 @@ class gurobi_direct ( OptSolver ):
                             linear_coefs.append( var_coefficient )
                             linear_vars.append( pyomo_gurobi_variable_map[label] )
     
-                        expr = LinExpr( coeffs=linear_coefs, vars=linear_vars )
-    
-                    constraint_label = self._symbol_map.getSymbol(constraint, labeler)
-    
-                    offset = 0.0
-                    if 0 in constraint_data.repn:
-                        offset = constraint_data.repn[0][None]
-                    bound = -offset
-    
+                        expr += LinExpr(linear_coefs, linear_vars)
+
+                    if 2 in expression: # quadratic constraint
+                        if GUROBI_VERSION_MAJOR < 5:
+                            raise ValueError, "The gurobi_direct plugin does not handle quadratic constraint expressions\
+                            \nfor Gurobi major versions < 5. Current version: Gurobi %s.%s%s" % gurobi.version()
+                        expr = QuadExpr(expr)
+                        hash_to_variable_map = expression[-1]
+                        for quad_repn, coef in expression[2].iteritems():
+                            gurobi_expr = QuadExpr(coef)
+                            for var_hash, exponent in quad_repn.iteritems():
+                                gurobi_var = pyomo_gurobi_variable_map[self._symbol_map.getSymbol(hash_to_variable_map[var_hash], labeler)]
+                                gurobi_expr *= gurobi_var 
+                                if exponent == 2:
+                                    gurobi_expr *= gurobi_var
+                            expr += gurobi_expr
+
                     if constraint_data._equality:
                         sense = GRB.EQUAL    # Fixed
                         bound = constraint_data.lower() - offset
                         grbmodel.addConstr(
-                           lhs=expr, sense=sense, rhs=bound, name=constraint_label )
+                            lhs=expr, sense=sense, rhs=bound, name=constraint_label )
                     else:
                         sense = GRB.LESS_EQUAL
                         if constraint_data.upper is not None:
                             bound = constraint_data.upper() - offset
                             if bound < float('inf'):
                                 grbmodel.addConstr(
-                                  lhs=expr,
-                                  sense=sense,
-                                  rhs=bound,
-                                  name='%s_Upper' % constraint_label
-                                )
-    
+                                    lhs=expr,
+                                    sense=sense,
+                                    rhs=bound,
+                                    name='%s_Upper' % constraint_label
+                                    )
+                                    
                         if constraint_data.lower is not None:
                             bound = constraint_data.lower() - offset
                             if bound > -float('inf'):
                                 grbmodel.addConstr(
-                                  lhs=bound,
-                                  sense=sense,
-                                  rhs=expr,
-                                  name=constraint_label
-                                )
-
+                                    lhs=bound,
+                                    sense=sense,
+                                    rhs=expr,
+                                    name=constraint_label
+                                    )
+        
         grbmodel.update()
 
         self._gurobi_instance = grbmodel
