@@ -39,6 +39,7 @@ class PyomoTestDriver(Plugin):
         global tmpdir
         tmpdir = os.getcwd()
         os.chdir(options.currdir)
+        pyutilib.services.TempfileManager.push()
         pyutilib.services.TempfileManager.sequential_files(0)
         pyutilib.services.TempfileManager.tempdir = options.currdir
         #
@@ -55,7 +56,7 @@ class PyomoTestDriver(Plugin):
 
     def tearDown(self, testcase, options):
         global tmpdir
-        pyutilib.services.TempfileManager.clear_tempfiles()
+        pyutilib.services.TempfileManager.pop()
         os.chdir(tmpdir)
         pyutilib.services.TempfileManager.unique_files()
 
