@@ -25,6 +25,9 @@ import filecmp
 import shutil
 
 
+def filter(line):
+    return 'Problem' in line or line.startswith('NAME')
+
 class MockArg(object):
 
     def __init__(self):
@@ -33,7 +36,7 @@ class MockArg(object):
     def valid_problem_types(self):
         return [ProblemFormat.pyomo]
 
-    def write(self,filename="", format=None, solver_capability=None):
+    def write(self,filename="", format=None, solver_capability=None, generate_symbolic_labels=False):
         return (filename,None)
 
 class MockArg2(MockArg):
@@ -41,7 +44,7 @@ class MockArg2(MockArg):
     def valid_problem_types(self):
         return [ProblemFormat.nl]
 
-    def write(self,filename="", format=None, solver_capability=None):
+    def write(self,filename="", format=None, solver_capability=None, generate_symbolic_labels=False):
         OUTPUT=open(filename,"w")
         INPUT=open(currdir+"test4.nl")
         for line in INPUT:
@@ -55,12 +58,12 @@ class MockArg3(MockArg):
     def valid_problem_types(self):
         return [ProblemFormat.mod]
 
-    def write(self,filename="", format=None, solver_capability=None):
+    def write(self,filename="", format=None, solver_capability=None, generate_symbolic_labels=False):
         return (filename,None)
 
 class MockArg4(MockArg):
 
-    def write(self,filename="", format=None, solver_capability=None):
+    def write(self,filename="", format=None, solver_capability=None, generate_symbolic_labels=False):
         OUTPUT=open(filename,"w")
         INPUT=open(currdir+"test4.nl")
         for line in INPUT:
@@ -120,8 +123,8 @@ class Test(unittest.TestCase):
             if not pyutilib.services.registered_executable("glpsol") is None:
                 self.fail("Unexpected ConverterError - glpsol is enabled but not available: '%s'" % str(err))
             return
-        self.assertEqual(ans[0],("glpsol.lp",))
-        self.assertFileEqualsBaseline(ans[0][0], currdir+"test2_convert.lp")
+        self.assertTrue(ans[0][0].endswith("glpsol.lp"))
+        self.assertFileEqualsBaseline(ans[0][0], currdir+"test2_convert.lp", filter=filter)
 
     def test_mod_lp2(self):
         """ Convert from MOD+DAT to LP """
@@ -135,8 +138,8 @@ class Test(unittest.TestCase):
             if not pyutilib.services.registered_executable("glpsol") is None:
                 self.fail("Unexpected ConverterError - glpsol is enabled but not available: '%s'" % str(err))
             return
-        self.assertEqual(ans[0],("glpsol.lp",))
-        self.assertFileEqualsBaseline(ans[0][0], currdir+"test3_convert.lp")
+        self.assertTrue(ans[0][0].endswith("glpsol.lp"))
+        self.assertFileEqualsBaseline(ans[0][0], currdir+"test3_convert.lp", filter=filter)
 
     def test_mod_nl1(self):
         """ Convert from MOD to NL """
