@@ -45,12 +45,12 @@ class test_ipopt(unittest.TestCase):
         self.asl = coopr.plugins.solvers.ASL(keepFiles=True, options={'solver':'ipopt'})
         self.asl.suffixes=['.*']
 
-        ver = subprocess.Popen(['ipopt','-v'],stdout=subprocess.PIPE).communicate()[0].split()[1]
-        if ver != '3.9.3':
-            for line in fileinput.input(currdir+"test_solve_from_nl.baseline",inplace=1):
-                    print line.replace('3.9.3',ver)
-            for line in fileinput.input(currdir+"test_solve_from_instance.baseline",inplace=1):
-                    print line.replace('3.9.3',ver)
+        #ver = subprocess.Popen(['ipopt','-v'],stdout=subprocess.PIPE).communicate()[0].split()[1]
+        #if ver != '3.9.3':
+        #    for line in fileinput.input(currdir+"test_solve_from_nl.baseline",inplace=1):
+        #            print line.replace('3.9.3',ver),
+        #    for line in fileinput.input(currdir+"test_solve_from_instance.baseline",inplace=1):
+        #            print line.replace('3.9.3',ver),
 
         # The sisser CUTEr instance
         # Formulated in Pyomo by Carl D. Laird, Daniel P. Word, Brandon C. Barrera and Saumyajyoti Chaudhuri
